==> monet-1.0.54-sources.jar: io/intino/monet/box/ui/resources/OrderTemplateProxyResource.java <==
package io.intino.monet.box.ui.resources;

import io.intino.monet.box.MonetBox;
import io.intino.monet.box.ui.pages.OrderTemplateProxyPage;
import io.intino.alexandria.Json;
import io.intino.alexandria.exceptions.AlexandriaException;
import io.intino.alexandria.exceptions.Unauthorized;
import io.intino.alexandria.ui.Soul;
import io.intino.alexandria.ui.displays.notifiers.DisplayNotifierProvider;
import io.intino.alexandria.ui.services.auth.exceptions.CouldNotObtainInfo;
import io.intino.alexandria.ui.services.push.UIClient;
import io.intino.alexandria.ui.services.push.UISession;

import java.util.function.Consumer;
import java.util.function.Function;

public class OrderTemplateProxyResource extends io.intino.alexandria.ui.spark.resources.ProxyResource {
	private final MonetBox box;

	public OrderTemplateProxyResource(MonetBox box, io.intino.alexandria.ui.spark.UISparkManager manager, DisplayNotifierProvider notifierProvider) {
		super(manager, notifierProvider);
		this.box = box;
	}

	@Override
	public void execute() throws AlexandriaException {
		fillBrowser(manager, session());
		fillDeviceParameter();
		render();
	}

	private void render() {
		UIClient client = client();

		OrderTemplateProxyPage page = new OrderTemplateProxyPage();
		page.session = session();
		page.session.browser().onRedirect(location -> manager.redirect(location));
		page.session.browser().requestUrl(manager.requestUrl());
		page.session.whenLogin(new Function<String, String>() {
			@Override
			public String apply(String baseUrl) {
				return OrderTemplateProxyResource.this.authenticate(page.session, baseUrl);
			}
		});
		page.session.whenLogout(b -> logout(page.session));
		page.box = box;
		page.clientId = client.id();
		page.googleApiKey = "";
		page.device = parameterValue("device");
		page.orderId = parameterValue("orderId");
		page.author = parameterValue("author");
		page.personifiedDisplay = parameterValue("personifiedDisplay");
        if (!page.hasPermissions()) {
            manager.redirect(page.redirectUrl());
            return;
        }

		Soul soul = soul();
		if (soul != null) {
			page.soul = soul;
			page.execute();
			return;
		}

		soul = new Soul(page.session) {
			@Override
			public void personify() {
				Soul soul = this;
				addRegisterDisplayListener(display -> {
					display.inject(notifier(page.session, client, display));
					display.inject(page.session);
					display.inject(soul);
					display.inject(() -> soul);
				});
			}
		};
		client.soul(soul);
		client.cookies(manager.cookies());
		page.soul = soul;
		page.execute();
		box.registerSoul(client.id(), soul);
		soul.register(new io.intino.alexandria.ui.displays.DisplayRouter(box).id("__router__"));
		//((io.intino.monet.box.ui.displays.RouteDispatcher)box.routeManager().routeDispatcher()).dispatchOrderTemplate(soul, page.orderId, page.author, page.personifiedDisplay);

        manager.pushService().onClose(page.clientId).execute(new Consumer<UIClient>() {
            @Override
            public void accept(io.intino.alexandria.ui.services.push.UIClient client) {
                box.soul(client.id()).ifPresent(s -> s.destroy());
                box.unRegisterSoul(client.id());
                manager.unRegister(client);
            }
        });

		manager.write("OK");
	}
}

==> monet-2.0.4-sources.jar: io/intino/monet/box/ui/resources/OrderTemplateProxyResource.java <==
package io.intino.monet.box.ui.resources;

import io.intino.monet.box.MonetBox;
import io.intino.monet.box.ui.pages.OrderTemplateProxyPage;
import io.intino.alexandria.Json;
import io.intino.alexandria.exceptions.AlexandriaException;
import io.intino.alexandria.exceptions.Unauthorized;
import io.intino.alexandria.ui.Soul;
import io.intino.alexandria.ui.displays.notifiers.DisplayNotifierProvider;
import io.intino.alexandria.ui.services.auth.exceptions.CouldNotObtainInfo;
import io.intino.alexandria.ui.services.push.UIClient;
import io.intino.alexandria.ui.services.push.UISession;

import java.util.function.Consumer;
import java.util.function.Function;

public class OrderTemplateProxyResource extends io.intino.alexandria.ui.spark.resources.ProxyResource {
	private final MonetBox box;

	public OrderTemplateProxyResource(MonetBox box, io.intino.alexandria.ui.spark.UISparkManager manager, DisplayNotifierProvider notifierProvider) {
		super(manager, notifierProvider);
		this.box = box;
	}

	@Override
	public void execute() throws AlexandriaException {
		fillBrowser(manager, session());
		fillDeviceParameter();
		render();
	}

	private void render() {
		UIClient client = client();

		OrderTemplateProxyPage page = new OrderTemplateProxyPage();
		page.session = session();
		page.session.browser().onRedirect(location -> manager.redirect(location));
		page.session.browser().requestUrl(manager.requestUrl());
		page.session.whenLogin(new Function<String, String>() {
			@Override
			public String apply(String baseUrl) {
				return OrderTemplateProxyResource.this.authenticate(page.session, baseUrl);
			}
		});
		page.session.whenLogout(b -> logout(page.session));
		page.box = box;
		page.clientId = client.id();
		page.googleApiKey = "";
		page.device = parameterValue("device");
		((OrderTemplateProxyPage)page).orderId = parameterValue("orderId");
		((OrderTemplateProxyPage)page).author = parameterValue("author");
		((OrderTemplateProxyPage)page).personifiedDisplay = parameterValue("personifiedDisplay");
		if (!page.hasPermissions()) {
			manager.redirect(page.redirectUrl());
			return;
		}

		Soul soul = soul();
		if (soul != null) {
			page.soul = soul;
			page.execute();
			return;
		}

		soul = new Soul(page.session) {
			@Override
			public void personify() {
				Soul soul = this;
				addRegisterDisplayListener(display -> {
					display.inject(notifier(page.session, client, display));
					display.inject(page.session);
					display.inject(soul);
					display.inject(() -> soul);
				});
			}
		};
		client.soul(soul);
		client.cookies(manager.cookies());
		page.soul = soul;
		page.execute();
		box.registerSoul(client.id(), soul);
		soul.register(new io.intino.alexandria.ui.displays.DisplayRouter(box).id("__router__"));
		//((io.intino.monet.box.ui.displays.RouteDispatcher)box.routeManager().routeDispatcher()).dispatchOrderTemplate(soul, ((OrderTemplateProxyPage)page).orderId, ((OrderTemplateProxyPage)page).author, ((OrderTemplateProxyPage)page).personifiedDisplay);

		manager.pushService().onClose(page.clientId).execute(new Consumer<UIClient>() {
			@Override
			public void accept(io.intino.alexandria.ui.services.push.UIClient client) {
				box.soul(client.id()).ifPresent(s -> s.destroy());
				box.unRegisterSoul(client.id());
				manager.unRegister(client);
			}
		});

		manager.write("OK");
	}
}
